#ifndef NT2_INCLUDE_CONSTANTS_INVPIO_2_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_INVPIO_2_HPP_INCLUDED

#include <nt2/trigonometric/include/constants/invpio_2.hpp>

#endif
